@@ -60,7 +60,11 @@ class MobileVersion(BaseVersion):
 
     _ALL_NUMBERS = BaseVersion._MANDATORY_NUMBERS + _OPTIONAL_NUMBERS
 
+    # Focus-Android and Fenix were the first ones to be converted to the Gecko
+    # pattern (bug 1777255)
     _FIRST_VERSION_TO_FOLLOW_GECKO_PATTERN = 104
+    # Android-Components later (bug 1800611)
+    _LAST_VERSION_TO_FOLLOW_MAVEN_PATTERN = 108
 
     build_number = attr.ib(type=int, converter=strictly_positive_int_or_none, default=None)
     beta_number = attr.ib(type=int, converter=strictly_positive_int_or_none, default=None)
@@ -82,10 +86,17 @@ class MobileVersion(BaseVersion):
                     'Beta number and patch number cannot be both defined',
                 ), (
                     self.release_candidate_number is not None,
-                    'Release candidate number cannot be defined after Mobile v104',
+                    'Release candidate number cannot be defined after Mobile v{}'.format(
+                        self._FIRST_VERSION_TO_FOLLOW_GECKO_PATTERN
+                    ),
                 ), (
-                    self.minor_number == 0 and self.patch_number == 0,
-                    'Minor number and patch number cannot be both equal to 0',
+                    self.major_number > self._LAST_VERSION_TO_FOLLOW_MAVEN_PATTERN and
+                    self.minor_number == 0 and
+                    self.patch_number == 0,
+                    'Minor number and patch number cannot be both equal to 0 past '
+                    'Mobile v{}'.format(
+                        self._LAST_VERSION_TO_FOLLOW_MAVEN_PATTERN
+                    ),
                 ), (
                     self.minor_number != 0 and self.patch_number is None,
                     'Patch number cannot be undefined if minor number is greater than 0',
@@ -97,10 +108,14 @@ class MobileVersion(BaseVersion):
                 pattern_message
                 for condition, pattern_message in ((
                     self.patch_number is None,
-                    'Patch number must be defined before Mobile v104',
+                    'Patch number must be defined before Mobile v{}'.format(
+                        self._FIRST_VERSION_TO_FOLLOW_GECKO_PATTERN
+                    ),
                 ), (
                     self.is_nightly,
-                    'Nightlies are not supported until Mobile v104',
+                    'Nightlies are not supported until Mobile v{}'.format(
+                        self._FIRST_VERSION_TO_FOLLOW_GECKO_PATTERN
+                    ),
                 ))
                 if condition
             ])
@@ -120,13 +135,17 @@ class MobileVersion(BaseVersion):
         if mobile_version.is_beta:
             if mobile_version.is_gecko_pattern and '-beta.' in version_string:
                 raise PatternNotMatchedError(
-                    mobile_version, ['"-beta." can only be used before Mobile v104']
+                    mobile_version, ['"-beta." can only be used before Mobile v{}'.format(
+                        cls._FIRST_VERSION_TO_FOLLOW_GECKO_PATTERN
+                    )]
                 )
             if not mobile_version.is_gecko_pattern and re.search(r"\db\d", version_string):
                 raise PatternNotMatchedError(
                     mobile_version, [
-                        '"b" cannot be used before Mobile v104 to define a '
-                        'beta version'
+                        '"b" cannot be used before Mobile v{} to define a '
+                        'beta version'.format(
+                            cls._FIRST_VERSION_TO_FOLLOW_GECKO_PATTERN
+                        )
                     ]
                 )
 
